==> netxms-4.1.401.tar.gz: netxms-4.1.401/src/client/nxmc/java/src/main/java/org/netxms/nxmc/modules/agentmanagement/views/helpers/DeploymentStatus.java <==
/**
 * NetXMS - open source network management system
 * Copyright (C) 2022 Raden Solutions
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
package org.netxms.nxmc.modules.agentmanagement.views.helpers;

import org.netxms.client.NXCSession;
import org.netxms.client.objects.AbstractNode;
import org.netxms.nxmc.Registry;

/**
 * Internal object used to hold package deployment status for specific node
 */
public class DeploymentStatus
{
	private long nodeId;
	private AbstractNode nodeObject;
	private int status;
	private String message;
	
	/**
	 * @param nodeId
	 * @param status
	 * @param message
	 */
	public DeploymentStatus(long nodeId, int status, String message)
	{
		this.nodeId = nodeId;
		this.nodeObject = (AbstractNode)((NXCSession)Registry.getSession()).findObjectById(nodeId, AbstractNode.class);
		this.status = status;
		this.message = message;
	}
	
	/**
	 * Get node name
	 * 
	 * @return
	 */
	public String getNodeName()
	{
		if (nodeObject == null)
		{
			nodeObject = (AbstractNode)((NXCSession)Registry.getSession()).findObjectById(nodeId, AbstractNode.class);
		}
		return (nodeObject != null) ? nodeObject.getObjectName() : ("[" + Long.toString(nodeId) + "]"); //$NON-NLS-1$ //$NON-NLS-2$
	}

	/**
	 * @return the status
	 */
	public int getStatus()
	{
		return status;
	}

	/**
	 * @param status the status to set
	 */
	public void setStatus(int status)
	{
		this.status = status;
	}

	/**
	 * @return the message
	 */
	public String getMessage()
	{
		return (message != null) ? message : ""; //$NON-NLS-1$
	}

	/**
	 * @param message the message to set
	 */
	public void setMessage(String message)
	{
		this.message = message;
	}

	/**
	 * @return the nodeObject
	 */
	public AbstractNode getNodeObject()
	{
		return nodeObject;
	}
}

==> netxms-5.0.8.tar.gz: netxms-5.0.8/src/client/nxmc/java/src/main/java/org/netxms/nxmc/modules/agentmanagement/views/helpers/DeploymentStatus.java <==
/**
 * NetXMS - open source network management system
 * Copyright (C) 2022 Raden Solutions
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
package org.netxms.nxmc.modules.agentmanagement.views.helpers;

import org.netxms.client.NXCSession;
import org.netxms.client.objects.AbstractNode;
import org.netxms.nxmc.Registry;

/**
 * Internal object used to hold package deployment status for specific node
 */
public class DeploymentStatus
{
	private long nodeId;
	private AbstractNode nodeObject;
	private int status;
	private String message;
	
	/**
	 * @param nodeId
	 * @param status
	 * @param message
	 */
	public DeploymentStatus(long nodeId, int status, String message)
	{
		this.nodeId = nodeId;
		this.nodeObject = null;
		this.status = status;
		this.message = message;
	}
	
	/**
	 * Get node name
	 * 
	 * @return
	 */
	public String getNodeName()
	{
		if (nodeObject == null)
		{
			nodeObject = (AbstractNode)((NXCSession)Registry.getSession()).findObjectById(nodeId, AbstractNode.class);
		}
		return (nodeObject != null) ? nodeObject.getObjectName() : ("[" + Long.toString(nodeId) + "]"); //$NON-NLS-1$ //$NON-NLS-2$
	}

	/**
	 * @return the status
	 */
	public int getStatus()
	{
		return status;
	}

	/**
	 * @param status the status to set
	 */
	public void setStatus(int status)
	{
		this.status = status;
	}

	/**
	 * @return the message
	 */
	public String getMessage()
	{
		return (message != null) ? message : ""; //$NON-NLS-1$
	}

	/**
	 * @param message the message to set
	 */
	public void setMessage(String message)
	{
		this.message = message;
	}

	/**
	 * @return the nodeObject
	 */
	public AbstractNode getNodeObject()
	{
      if (nodeObject == null)
      {
         nodeObject = (AbstractNode)((NXCSession)Registry.getSession()).findObjectById(nodeId, AbstractNode.class);
      }
		return nodeObject;
	}
}
